/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Core {

    /// <summary>
    /// Represents a <see cref="RelaxedPlanner">relaxed planner</see> <see cref="Action">action</see> layer node.
    /// </summary>
    [Serializable]
    internal sealed class ActionLayerNode : LayerNode<ActionLayerNode> {

        #region Fields

        /// <summary>
        /// The <see cref="T:Action">action</see>.
        /// </summary>
        internal Action Action;

        /// <summary>
        /// The number of reached preconditions of the <see cref="F:Action">action</see>.
        /// </summary>
        internal int ReachedPreconditionsCount;

        /// <summary>
        /// The difficulty of reach the <see cref="F:Action">action</see>.
        /// </summary>
        internal int Difficulty;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ActionLayerNode"/> class.
        /// </summary>
        /// <param name="action">The action.</param>
        internal ActionLayerNode(Action action) {
            Action = action;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ActionLayerNode"/> class.
        /// </summary>
        /// <param name="layerIndex">The layer index.</param>
        /// <param name="action">The action.</param>
        internal ActionLayerNode(int layerIndex, Action action) {
            LayerIndex = layerIndex;
            Action = action;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Clears the node.
        /// </summary>
        internal override void Clear() {
            if (Action.Preconditions.Length != 0) {
                base.Clear();
                ReachedPreconditionsCount = 0;
                Difficulty = 0;
            }
        }

        #endregion

    }

}
