/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Core {

    /// <summary>
    /// Represents a <see cref="State">state</see> condition.
    /// </summary>
    /// <remarks>
    /// <para>A <see cref="State">state</see> condition typically must be check in run time because of the
    /// impossibility of knowing previously its value.</para>
    /// </remarks>
    [CLSCompliant(true)]
    public interface ICondition {

        #region Methods

        /// <summary>
        /// Determines whether this <see cref="ICondition">condition</see> is true in a specified
        /// <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which check this
        /// <see cref="ICondition">condition</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>, as a performance improvement.
        /// If needed, correction checks must be done previously to the call of this method.</para>
        /// <para>It does not modify <paramref name="state"/>.</para>
        /// </remarks>
        /// <returns>
        /// True if this <see cref="ICondition">condition</see> is true in <paramref name="state"/>; false
        /// otherwise.
        /// </returns>
        bool IsTrueIn(State state);

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this <see cref="ICondition">condition</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this <see cref="ICondition">condition</see>.</returns>
        string ToString();

        #endregion

    }

}
