/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Core {

    /// <summary>
    /// Represents a <see cref="State">state</see> calculated value.
    /// </summary>
    /// <remarks>
    /// <para>A <see cref="State">state</see> calculated value can not be known until run time because of
    /// its dependencies with other non-precalculated values, which are those which also can only be known at
    /// run time.</para>
    /// </remarks>
    [CLSCompliant(true)]
    public interface IFunction {

        #region Methods

        /// <summary>
        /// Returns the result value of this <see cref="IFunction">function</see> in a specified
        /// <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which calculate the result value of this
        /// <see cref="IFunction">function</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>. If needed, correction checks
        /// must be done previously to the call of this method.</para>
        /// <para>It does not modify <paramref name="state"/>.</para>
        /// </remarks>
        /// <returns>
        /// The result value of this <see cref="IFunction">function</see> in <paramref name="state"/>.
        /// </returns>
        float GetResultIn(State state);

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this <see cref="IFunction">function</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this <see cref="IFunction">function</see>.</returns>
        string ToString();

        #endregion

    }

}