/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Core {

    /// <summary>
    /// Represents a <see cref="RelaxedPlanner">relaxed planner</see> layer.
    /// </summary>
    /// <typeparam name="T">The type of the <see cref="LayerNode{T}">node</see>s.</typeparam>
    [Serializable]
    internal sealed class Layer<T> : NodeList<T> where T : LayerNode<T> {

        #region Constants

        /// <summary>
        /// The constant which represents no <see cref="Index">index</see>.
        /// </summary>
        internal const int NoIndex = -1;

        #endregion

        #region Fields

        /// <summary>
        /// The layer index.
        /// </summary>
        internal int Index;

        /// <summary>
        /// The next layer.
        /// </summary>
        internal Layer<T> Next;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="Layer{T}"/> class.
        /// </summary>
        internal Layer() {
            //do nothing
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Layer{T}"/> class.
        /// </summary>
        /// <param name="index">The layer index.</param>
        internal Layer(int index) {
            Index = index;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Adds the specified node.
        /// </summary>
        /// <param name="node">The node.</param>
        /// <returns>
        /// True if <paramref name="node"/> is added; false otherwise.
        /// </returns>
        internal override bool Add(T node) {
            bool added = (node.LayerIndex == NoIndex);
            if (added) {
                base.Add(node);
                node.LayerIndex = Index;
            }
            return added;
        }

        #endregion

    }

}
