/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Core {

    /// <summary>
    /// Represents a <see cref="RelaxedPlanner">relaxed planner</see> layer node.
    /// </summary>
    /// <typeparam name="T">The type of the <see cref="LayerNode{T}">node</see>s.</typeparam>
    [Serializable]
    internal abstract class LayerNode<T> : Node<T> where T : LayerNode<T> {

        #region Fields

        /// <summary>
        /// The layer index.
        /// </summary>
        internal int LayerIndex;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="LayerNode{T}"/> class.
        /// </summary>
        internal LayerNode() {
            LayerIndex = Layer<T>.NoIndex;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Clears the node.
        /// </summary>
        internal override void Clear() {
            base.Clear();
            LayerIndex = Layer<T>.NoIndex;
        }

        #endregion

    }

}
