/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Core {

    /// <summary>
    /// Represents a linked list of nodes.
    /// </summary>
    /// <typeparam name="T">The type of the nodes.</typeparam>
    [Serializable]
    internal class NodeList<T> where T : Node<T> {

        #region Fields

        /// <summary>
        /// The first node.
        /// </summary>
        public T FirstNode;

        /// <summary>
        /// The last node.
        /// </summary>
        public T LastNode;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="NodeList{T}"/> class.
        /// </summary>
        internal NodeList() {
            //do nothing
        }

        #endregion

        #region Methods

        /// <summary>
        /// Adds the specified node.
        /// </summary>
        /// <param name="node">The node.</param>
        /// <returns>
        /// True if <paramref name="node"/> is added; false otherwise.
        /// </returns>
        internal virtual bool Add(T node) {
            if (FirstNode == null) {
                FirstNode = node;
            } else {
                LastNode.Next = node;
            }
            LastNode = node;
            return true;
        }

        /// <summary>
        /// Clears the list.
        /// </summary>
        internal void Clear() {
            FirstNode = null;
            LastNode = null;
        }

        #endregion

    }

}
