/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Core {

    /// <summary>
    /// Represents a node of a relaxed plan.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class RelaxedPlanNode : Node<RelaxedPlanNode> {

        #region Constants

        /// <summary>
        /// The constant which represents no <see cref="RelaxedPlanNode">node</see>.
        /// </summary>
        public const RelaxedPlanNode None = null;

        #endregion

        #region Fields

        /// <summary>
        /// The action contained in this <see cref="RelaxedPlanNode">node</see>.
        /// </summary>
        public readonly Action Action;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="RelaxedPlanNode"/> class.
        /// </summary>
        /// <param name="action">The action contained in the <see cref="RelaxedPlanNode">node</see>.</param>
        internal RelaxedPlanNode(Action action) {
            Action = action;
        }

        #endregion

    }

}
