/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents an <see cref="Action">action</see>-dependant <see cref="State">state</see> <see cref="IActionFunction">calculated value</see> which adds a constant value to a global variable value.
    /// </summary>
    /// <remarks><para>It is recommended to use the optimized variant <see cref="ActionGlobalVariableOneSum"></see> if the constant value is 1.</para></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class ActionGlobalVariableConstantSum : IActionFunction {

        #region Fields

        /// <summary>
        /// The index of the <see cref="Action.Variables">action variable</see> which provides the index of the global variable.
        /// </summary>
        private readonly int _globalVariableIndex;

        /// <summary>
        /// The constant value.
        /// </summary>
        private readonly float _constantValue;

        /// <summary>
        /// Global variables values.
        /// </summary>
        private readonly float[] _globalVariables;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ActionGlobalVariableConstantSum"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of both <paramref name="globalVariableIndex"/> and <paramref name="constantValue"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para><para>It is recommended to use the optimized variant <see cref="ActionGlobalVariableOneSum"></see> if <paramref name="constantValue"/> is 1.</para></remarks>
        /// <param name="globalVariableIndex">The index of the <see cref="Action.Variables">action variable</see> which provides the index of the global variable.</param>
        /// <param name="constantValue">The constant value.</param>
        /// <param name="globalVariables">Global variables values.</param>
        public ActionGlobalVariableConstantSum(int globalVariableIndex, float constantValue, float[] globalVariables) {
            _globalVariableIndex = globalVariableIndex;
            _constantValue = constantValue;
            _globalVariables = globalVariables;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Returns the result value of this <see cref="IActionFunction">function</see> in a specified
        /// <see cref="State">state</see>, taking into account the information provided by an
        /// <see cref="Action">action</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which calculate the result value of this
        /// <see cref="IActionFunction">function</see>.</param>
        /// <param name="action">The <see cref="Action">action</see> to take into account.</param>
        /// <remarks><para>Assumes the correction of both <paramref name="state"/> and
        /// <paramref name="action"/>, as a performance improvement. If needed, correction checks must be
        /// done previously to the call of this method.</para>
        /// <para>It does not modify neither <paramref name="state"/> nor <paramref name="action"/>.</para>
        /// </remarks>
        /// <returns>
        /// The result value of this <see cref="IActionFunction">function</see> in <paramref name="state"/>,
        /// taking into account the information provided by <paramref name="action"/>.
        /// </returns>
        public float GetResultIn(State state, Action action) {
            return _globalVariables[action.Variables[_globalVariableIndex]] + _constantValue;
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="IActionFunction">function</see>, taking into account the information provided by
        /// an <see cref="Action">action</see>.
        /// </summary>
        /// <param name="action">The <see cref="Action">action</see> to take into account.</param>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="IActionFunction">function</see>, taking into account the information provided
        /// by <paramref name="action"/>.</returns>
        public string ToString(Action action) {
            return "gv" + action.Variables[_globalVariableIndex] + " + " + _constantValue;
        }

        #endregion

    }

}