/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents an <see cref="Action">action</see>-dependant <see cref="State">state</see> <see cref="IActionCondition">condition</see> which checks if a <see cref="IActionFunction.GetResultIn">funcion result</see> value is greater than or equal to another <see cref="IActionFunction.GetResultIn">funcion result</see> value.
    /// </summary>
    /// <remarks></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class ActionResultResultNonInferiority : IActionCondition {

        #region Fields

        /// <summary>
        /// The <see cref="IActionFunction">function</see> to be called in order to <see cref="IActionFunction.GetResultIn">get the result</see> value.
        /// </summary>
        private readonly IActionFunction _function;

        /// <summary>
        /// The <see cref="IActionFunction">function</see> to be called in order to <see cref="IActionFunction.GetResultIn">get the other result</see> value.
        /// </summary>
        private readonly IActionFunction _otherFunction;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ActionResultResultNonInferiority"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of both <paramref name="function"/> and <paramref name="otherFunction"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para></remarks>
        /// <param name="function">The <see cref="IActionFunction">function</see> to be called in order to <see cref="IActionFunction.GetResultIn">get the result</see> value.</param>
        /// <param name="otherFunction">The <see cref="IActionFunction">function</see> to be called in order to <see cref="IActionFunction.GetResultIn">get the other result</see> value.</param>
        public ActionResultResultNonInferiority(IActionFunction function, IActionFunction otherFunction) {
            _function = function;
            _otherFunction = otherFunction;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Determines whether this <see cref="IActionCondition">condition</see> is true in a specified
        /// <see cref="State">state</see>, taking into account the information provided by an
        /// <see cref="Action">action</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which check this
        /// <see cref="IActionCondition">condition</see>.</param>
        /// <param name="action">The <see cref="Action">action</see> to take into account.</param>
        /// <remarks><para>Assumes the correction of both <paramref name="state"/> and
        /// <paramref name="action"/>, as a performance improvement. If needed, correction checks must be
        /// done previously to the call of this method.</para>
        /// <para>It does not modify neither <paramref name="state"/> nor <paramref name="action"/>.</para>
        /// </remarks>
        /// <returns>
        /// True if this <see cref="IActionCondition">condition</see> is true in <paramref name="state"/>,
        /// taking into account the information provided by <paramref name="action"/>; false otherwise.
        /// </returns>
        public bool IsTrueIn(State state, Action action) {
            return _function.GetResultIn(state, action) >= _otherFunction.GetResultIn(state, action);
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="IActionCondition">condition</see>, taking into account the information provided by
        /// an <see cref="Action">action</see>.
        /// </summary>
        /// <param name="action">The <see cref="Action">action</see> to take into account.</param>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="IActionCondition">condition</see>, taking into account the information provided by
        /// <paramref name="action"/>.</returns>
        public string ToString(Action action) {
            return "(" + _function.ToString(action) + ") >= (" + _otherFunction.ToString(action) + ")";
        }

        #endregion

    }

}