/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents an <see cref="Action">action</see>-dependant <see cref="State">state</see> <see cref="IActionCondition">condition</see> which checks if a <see cref="State.Variables">state variable</see> value is equal to a global variable value.
    /// </summary>
    /// <remarks></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class ActionVariableGlobalVariableEquality : IActionCondition {

        #region Fields

        /// <summary>
        /// The index of the <see cref="Action.Variables">action variable</see> which provides the index of the <see cref="State.Variables">state variable</see>.
        /// </summary>
        private readonly int _actionVariableIndex;

        /// <summary>
        /// The index of the <see cref="Action.Variables">action variable</see> which provides the index of the global variable.
        /// </summary>
        private readonly int _globalVariableIndex;

        /// <summary>
        /// Global variables values.
        /// </summary>
        private readonly float[] _globalVariables;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ActionVariableGlobalVariableEquality"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of both <paramref name="actionVariableIndex"/> and <paramref name="globalVariableIndex"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para></remarks>
        /// <param name="actionVariableIndex">The index of the <see cref="Action.Variables">action variable</see> which provides the index of the <see cref="State.Variables">state variable</see>.</param>
        /// <param name="globalVariableIndex">The index of the <see cref="Action.Variables">action variable</see> which provides the index of the global variable.</param>
        /// <param name="globalVariables">Global variables values.</param>
        public ActionVariableGlobalVariableEquality(int actionVariableIndex, int globalVariableIndex, float[] globalVariables) {
            _actionVariableIndex = actionVariableIndex;
            _globalVariableIndex = globalVariableIndex;
            _globalVariables = globalVariables;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Determines whether this <see cref="IActionCondition">condition</see> is true in a specified
        /// <see cref="State">state</see>, taking into account the information provided by an
        /// <see cref="Action">action</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which check this
        /// <see cref="IActionCondition">condition</see>.</param>
        /// <param name="action">The <see cref="Action">action</see> to take into account.</param>
        /// <remarks><para>Assumes the correction of both <paramref name="state"/> and
        /// <paramref name="action"/>, as a performance improvement. If needed, correction checks must be
        /// done previously to the call of this method.</para>
        /// <para>It does not modify neither <paramref name="state"/> nor <paramref name="action"/>.</para>
        /// </remarks>
        /// <returns>
        /// True if this <see cref="IActionCondition">condition</see> is true in <paramref name="state"/>,
        /// taking into account the information provided by <paramref name="action"/>; false otherwise.
        /// </returns>
        public bool IsTrueIn(State state, Action action) {
            return state.Variables[action.Variables[_actionVariableIndex]] == _globalVariables[action.Variables[_globalVariableIndex]];
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="IActionCondition">condition</see>, taking into account the information provided by
        /// an <see cref="Action">action</see>.
        /// </summary>
        /// <param name="action">The <see cref="Action">action</see> to take into account.</param>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="IActionCondition">condition</see>, taking into account the information provided by
        /// <paramref name="action"/>.</returns>
        public string ToString(Action action) {
            return "v" + action.Variables[_actionVariableIndex] + " == gv" + action.Variables[_globalVariableIndex];
        }

        #endregion

    }

}