/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents a <see cref="State">state</see> effect which assigns to a global variable value the resulting value of adding a constant value to it.
    /// </summary>
    /// <remarks><para>It is recommended to use the optimized variant <see cref="GlobalVariableOneSumAssignment"></see> if the constant value is 1.</para></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class GlobalVariableConstantSumAssignment : IEffect {

        #region Fields

        /// <summary>
        /// The index of the global variable.
        /// </summary>
        private readonly int _globalVariableIndex;

        /// <summary>
        /// The constant value.
        /// </summary>
        private readonly float _constantValue;

        /// <summary>
        /// Global variables values.
        /// </summary>
        private readonly float[] _globalVariables;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="GlobalVariableConstantSumAssignment"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of both <paramref name="globalVariableIndex"/> and <paramref name="constantValue"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para><para>It is recommended to use the optimized variant <see cref="GlobalVariableOneSumAssignment"></see> if <paramref name="constantValue"/> is 1.</para></remarks>
        /// <param name="globalVariableIndex">The index of the global variable.</param>
        /// <param name="constantValue">The constant value.</param>
        /// <param name="globalVariables">Global variables values.</param>
        public GlobalVariableConstantSumAssignment(int globalVariableIndex, float constantValue, float[] globalVariables) {
            _globalVariableIndex = globalVariableIndex;
            _constantValue = constantValue;
            _globalVariables = globalVariables;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Applies this <see cref="IEffect">effect</see> to a specified <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> to which apply this
        /// <see cref="IEffect">effect</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>, as a performance
		/// improvement. If needed, correction checks must be done previously to the call of this
		/// method.</para>
        /// <para>It can modify <paramref name="state"/>.</para>
        /// </remarks>
        public void ApplyTo(State state) {
            _globalVariables[_globalVariableIndex] += _constantValue;
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="IEffect">effect</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="IEffect">effect</see>.</returns>
        public override string ToString() {
            return "gv" + _globalVariableIndex + " += " + _constantValue;
        }

        #endregion

    }

}