/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;
using System.Text;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents an <see cref="IEffect">effect</see> which applies multiple <see cref="IEffect">effect</see>s.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class MultipleEffectList : IEffect {

        #region Fields

        /// <summary>
        /// The <see cref="IEffect">effect</see>s.
        /// </summary>
        private readonly IEffect[] _effects;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MultipleEffectList"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of <paramref name="effects"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para></remarks>
        /// <param name="effects">The <see cref="IEffect">effect</see>s.</param>
        public MultipleEffectList(params IEffect[] effects) {
            _effects = effects;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Applies this <see cref="IEffect">effect</see> to a specified <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> to which apply this
        /// <see cref="IEffect">effect</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>, as a performance
		/// improvement. If needed, correction checks must be done previously to the call of this
		/// method.</para>
        /// <para>It can modify <paramref name="state"/>.</para>
        /// </remarks>
        public void ApplyTo(State state) {
            foreach (IEffect effect in _effects) {
                effect.ApplyTo(state);
            }
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="IEffect">effect</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="IEffect">effect</see>.</returns>
        public override string ToString() {
            StringBuilder buffer = new StringBuilder();
            bool isFirst = true;
            foreach (IEffect effect in _effects) {
                if (isFirst) {
                    isFirst = false;
                    buffer.Append("(");
                } else {
                    buffer.Append(" && (");
                }
                buffer.Append(effect.ToString());
                buffer.Append(")");
            }
            return buffer.ToString();
        }

        #endregion

    }

}