/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents a <see cref="State">state</see> <see cref="ICondition">condition</see> which checks if a <see cref="IFunction.GetResultIn">funcion result</see> value is distict from the constant value 0.
    /// </summary>
    /// <remarks></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class ResultZeroInequality : ICondition {

        #region Fields

        /// <summary>
        /// The <see cref="IFunction">function</see> to be called in order to <see cref="IFunction.GetResultIn">get the result</see> value.
        /// </summary>
        private readonly IFunction _function;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ResultZeroInequality"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of <paramref name="function"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para></remarks>
        /// <param name="function">The <see cref="IFunction">function</see> to be called in order to <see cref="IFunction.GetResultIn">get the result</see> value.</param>
        public ResultZeroInequality(IFunction function) {
            _function = function;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Determines whether this <see cref="ICondition">condition</see> is true in a specified
        /// <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which check this
        /// <see cref="ICondition">condition</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>, as a performance improvement.
        /// If needed, correction checks must be done previously to the call of this method.</para>
        /// <para>It does not modify <paramref name="state"/>.</para>
        /// </remarks>
        /// <returns>
        /// True if this <see cref="ICondition">condition</see> is true in <paramref name="state"/>; false
        /// otherwise.
        /// </returns>
        public bool IsTrueIn(State state) {
            return _function.GetResultIn(state) != 0;
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="ICondition">condition</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="ICondition">condition</see>.</returns>
        public override string ToString() {
            return "(" + _function.ToString() + ") != 0";
        }

        #endregion

    }

}