/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents a <see cref="State">state</see> <see cref="IFunction">calculated value</see> which adds a constant value to a <see cref="State.Variables">state variable</see> value.
    /// </summary>
    /// <remarks><para>It is recommended to use the optimized variant <see cref="VariableOneSum"></see> if the constant value is 1.</para></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class VariableConstantSum : IFunction {

        #region Fields

        /// <summary>
        /// The index of the <see cref="State.Variables">state variable</see>.
        /// </summary>
        private readonly int _variableIndex;

        /// <summary>
        /// The constant value.
        /// </summary>
        private readonly float _constantValue;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="VariableConstantSum"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of both <paramref name="variableIndex"/> and <paramref name="constantValue"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para><para>It is recommended to use the optimized variant <see cref="VariableOneSum"></see> if <paramref name="constantValue"/> is 1.</para></remarks>
        /// <param name="variableIndex">The index of the <see cref="State.Variables">state variable</see>.</param>
        /// <param name="constantValue">The constant value.</param>
        public VariableConstantSum(int variableIndex, float constantValue) {
            _variableIndex = variableIndex;
            _constantValue = constantValue;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Returns the result value of this <see cref="IFunction">function</see> in a specified
        /// <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which calculate the result value of this
        /// <see cref="IFunction">function</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>. If needed, correction checks
        /// must be done previously to the call of this method.</para>
        /// <para>It does not modify <paramref name="state"/>.</para>
        /// </remarks>
        /// <returns>
        /// The result value of this <see cref="IFunction">function</see> in <paramref name="state"/>.
        /// </returns>
        public float GetResultIn(State state) {
            return state.Variables[_variableIndex] + _constantValue;
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="IFunction">function</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="IFunction">function</see>.</returns>
        public override string ToString() {
            return "v" + _variableIndex + " + " + _constantValue;
        }

        #endregion

    }

}