/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents a <see cref="State">state</see> effect which assigns to a <see cref="State.Variables">state variable</see> value the resulting value of subtracting the constant value 1 from it.
    /// </summary>
    /// <remarks></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class VariableOneSubtractionAssignment : IEffect {

        #region Fields

        /// <summary>
        /// The index of the <see cref="State.Variables">state variable</see>.
        /// </summary>
        private readonly int _variableIndex;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="VariableOneSubtractionAssignment"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of <paramref name="variableIndex"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para></remarks>
        /// <param name="variableIndex">The index of the <see cref="State.Variables">state variable</see>.</param>
        public VariableOneSubtractionAssignment(int variableIndex) {
            _variableIndex = variableIndex;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Applies this <see cref="IEffect">effect</see> to a specified <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> to which apply this
        /// <see cref="IEffect">effect</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>, as a performance
		/// improvement. If needed, correction checks must be done previously to the call of this
		/// method.</para>
        /// <para>It can modify <paramref name="state"/>.</para>
        /// </remarks>
        public void ApplyTo(State state) {
            state.Variables[_variableIndex] -= 1;
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="IEffect">effect</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="IEffect">effect</see>.</returns>
        public override string ToString() {
            return "v" + _variableIndex + " -= 1";
        }

        #endregion

    }

}