/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

//NOTE: this class was automatically generated

using System;

using Aran.Core;

namespace Aran.Functional {

    /// <summary>
    /// Represents a <see cref="State">state</see> <see cref="ICondition">condition</see> which checks if a <see cref="State.Variables">state variable</see> value is equal to another <see cref="State.Variables">state variable</see> value.
    /// </summary>
    /// <remarks></remarks>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class VariableVariableEquality : ICondition {

        #region Fields

        /// <summary>
        /// The index of the <see cref="State.Variables">state variable</see>.
        /// </summary>
        private readonly int _variableIndex;

        /// <summary>
        /// The index of the other <see cref="State.Variables">state variable</see>.
        /// </summary>
        private readonly int _otherVariableIndex;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="VariableVariableEquality"/> class.
        /// </summary>
        /// <remarks><para>Assumes the correction of both <paramref name="variableIndex"/> and <paramref name="otherVariableIndex"/>, as a performance improvement. If needed, correction checks must be done previously to the call of this constructor.</para></remarks>
        /// <param name="variableIndex">The index of the <see cref="State.Variables">state variable</see>.</param>
        /// <param name="otherVariableIndex">The index of the other <see cref="State.Variables">state variable</see>.</param>
        public VariableVariableEquality(int variableIndex, int otherVariableIndex) {
            _variableIndex = variableIndex;
            _otherVariableIndex = otherVariableIndex;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Determines whether this <see cref="ICondition">condition</see> is true in a specified
        /// <see cref="State">state</see>.
        /// </summary>
        /// <param name="state">The <see cref="State">state</see> in which check this
        /// <see cref="ICondition">condition</see>.</param>
        /// <remarks><para>Assumes the correction of <paramref name="state"/>, as a performance improvement.
        /// If needed, correction checks must be done previously to the call of this method.</para>
        /// <para>It does not modify <paramref name="state"/>.</para>
        /// </remarks>
        /// <returns>
        /// True if this <see cref="ICondition">condition</see> is true in <paramref name="state"/>; false
        /// otherwise.
        /// </returns>
        public bool IsTrueIn(State state) {
            return state.Variables[_variableIndex] == state.Variables[_otherVariableIndex];
        }

        /// <summary>
        /// Returns a <see cref="String">string</see> that represents this
        /// <see cref="ICondition">condition</see>.
        /// </summary>
        /// <returns>A <see cref="String">string</see> that represents this
        /// <see cref="ICondition">condition</see>.</returns>
        public override string ToString() {
            return "v" + _variableIndex + " == v" + _otherVariableIndex;
        }

        #endregion

    }

}