/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Planning.Xml.Command {

    /// <summary>
    /// Represents a <see cref="XmlPlannerCommand">command line XML planner</see> default option value.
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public static class XmlPlannerCommandDefaultValue {

        #region Constants

        /// <summary>
        /// The default domain option value.
        /// </summary>
        public const string Domain = XmlPlannerDefaultValue.DomainPath;

        /// <summary>
        /// The default problem option value.
        /// </summary>
        public const string Problem = XmlPlannerDefaultValue.ProblemPath;

        /// <summary>
        /// The default output option value.
        /// </summary>
        public const string Out = XmlPlannerDefaultValue.OutputPath;

        /// <summary>
        /// The default root type option value.
        /// </summary>
        public const string RootType = XmlPlannerDefaultValue.RootType;

        /// <summary>
        /// The default root inequality option value.
        /// </summary>
        public const string RootInequality = "notEqual";

        /// <summary>
        /// The default encoding option value.
        /// </summary>
        public const string Encoding = XmlPlannerCommandEncoding.Problem;

        /// <summary>
        /// The default algorithms option value.
        /// </summary>
        private static readonly string[] _algorithms = {
            XmlPlannerCommandAlgorithm.GetAlgorithmName(XmlPlannerSearchAlgorithmId.EnforcedHillClimbing),
            XmlPlannerCommandAlgorithm.GetAlgorithmName(XmlPlannerSearchAlgorithmId.AStar)};

        /// <summary>
        /// The default beam width option value.
        /// </summary>
        public const int BeamWidth = XmlPlannerSearchAlgorithm.DefaultBeamWidth;

        /// <summary>
        /// The default heuristic weight option value.
        /// </summary>
        public const float HeuristicWeight = XmlPlannerSearchAlgorithm.DefaultHeuristicWeight;

        #endregion

        #region Methods

        /// <summary>
        /// The default domain option value.
        /// </summary>
        public static string[] GetAlgorithms() {
            return _algorithms.Clone() as string[];
        }

        #endregion

    }

}
