/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Planning.Xml.Command {

    /// <summary>
    /// Represents a <see cref="XmlPlannerCommand">command line XML planner</see> option name.
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public static class XmlPlannerCommandOption {

        #region Constants

        /// <summary>
        /// The domain option name.
        /// </summary>
        public static readonly string Domain = XmlPlannerCommand.GetOptionDependingOnPlattform("domain");

        /// <summary>
        /// The problem option name.
        /// </summary>
        public static readonly string Problem = XmlPlannerCommand.GetOptionDependingOnPlattform("problem");

        /// <summary>
        /// The output option name.
        /// </summary>
        public static readonly string Out = XmlPlannerCommand.GetOptionDependingOnPlattform("out");

        /// <summary>
        /// The maximum plan length option name.
        /// </summary>
        public static readonly string MaxPlanLength = XmlPlannerCommand.GetOptionDependingOnPlattform("maxPlanLength");

        /// <summary>
        /// The maximum planning time option name.
        /// </summary>
        public static readonly string MaxTime = XmlPlannerCommand.GetOptionDependingOnPlattform("maxTime");

        /// <summary>
        /// The search algorithm option name.
        /// </summary>
        public static readonly string Algorithm = XmlPlannerCommand.GetOptionDependingOnPlattform("algorithm");

        /// <summary>
        /// The beam width option name.
        /// </summary>
        public static readonly string BeamWidth = XmlPlannerCommand.GetOptionDependingOnPlattform("beamWidth");

        /// <summary>
        /// The heuristic weight name.
        /// </summary>
        public static readonly string HeuristicWeight = XmlPlannerCommand.GetOptionDependingOnPlattform("heuristicWeight");

        /// <summary>
        /// The root type option name.
        /// </summary>
        public static readonly string RootType = XmlPlannerCommand.GetOptionDependingOnPlattform("rootType");

        /// <summary>
        /// The root type disabling option name.
        /// </summary>
        public static readonly string NoRoot = XmlPlannerCommand.GetOptionDependingOnPlattform("noRoot");

        /// <summary>
        /// The root type inequality option name.
        /// </summary>
        public static readonly string RootInequality = XmlPlannerCommand.GetOptionDependingOnPlattform("rootInequality");

        /// <summary>
        /// The root type inequality disabling option name.
        /// </summary>
        public static readonly string NoRootInequality = XmlPlannerCommand.GetOptionDependingOnPlattform("noRootInequality");

        /// <summary>
        /// The inequality option name.
        /// </summary>
        public static readonly string Inequality = XmlPlannerCommand.GetOptionDependingOnPlattform("inequality");

        /// <summary>
        /// The help option name.
        /// </summary>
        public static readonly string Help = XmlPlannerCommand.GetOptionDependingOnPlattform("help");

        /// <summary>
        /// The header disabling option name.
        /// </summary>
        public static readonly string NoLogo = XmlPlannerCommand.GetOptionDependingOnPlattform("noLogo");

        /// <summary>
        /// The encoding option name.
        /// </summary>
        public static readonly string Encoding = XmlPlannerCommand.GetOptionDependingOnPlattform("encoding");

        /// <summary>
        /// The input XML schema export option name.
        /// </summary>
        public static readonly string ExportInputSchema = XmlPlannerCommand.GetOptionDependingOnPlattform("exportInputSchema");

        /// <summary>
        /// The output XML schema export option name.
        /// </summary>
        public static readonly string ExportOutputSchema = XmlPlannerCommand.GetOptionDependingOnPlattform("exportOutputSchema");

        /// <summary>
        /// The license export option name.
        /// </summary>
        public static readonly string ExportLicense = XmlPlannerCommand.GetOptionDependingOnPlattform("exportLicense");

        /// <summary>
        /// The output overwriting option name.
        /// </summary>
        public static readonly string Overwrite = XmlPlannerCommand.GetOptionDependingOnPlattform("overwrite");

        /// <summary>
        /// The warning disabling option name.
        /// </summary>
        public static readonly string NoWarn = XmlPlannerCommand.GetOptionDependingOnPlattform("noWarn");

        /// <summary>
        /// The warning as errors option name.
        /// </summary>
        public static readonly string WarnAsError = XmlPlannerCommand.GetOptionDependingOnPlattform("warnAsError");

        /// <summary>
        /// The verbose option name.
        /// </summary>
        public static readonly string Verbose = XmlPlannerCommand.GetOptionDependingOnPlattform("verbose");

        /// <summary>
        /// The language option name.
        /// </summary>
        public static readonly string Language = XmlPlannerCommand.GetOptionDependingOnPlattform("language");

        #endregion

    }

}
