/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Planning.Xml.Command {

    /// <summary>
    /// Represents a <see cref="XmlPlannerCommand">command line XML planner</see> option short name.
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public static class XmlPlannerCommandShortOption {

        #region Constants

        /// <summary>
        /// The domain option short name.
        /// </summary>
        public static readonly string Domain = XmlPlannerCommand.GetOptionDependingOnPlattform("d");

        /// <summary>
        /// The problem option short name.
        /// </summary>
        public static readonly string Problem = XmlPlannerCommand.GetOptionDependingOnPlattform("p");

        /// <summary>
        /// The output option short name.
        /// </summary>
        public static readonly string Out = XmlPlannerCommand.GetOptionDependingOnPlattform("o");

        /// <summary>
        /// The search algorithm option short name.
        /// </summary>
        public static readonly string Algorithm = XmlPlannerCommand.GetOptionDependingOnPlattform("a");

        /// <summary>
        /// The beam width option short name.
        /// </summary>
        public static readonly string BeamWidth = XmlPlannerCommand.GetOptionDependingOnPlattform("b");

        /// <summary>
        /// The heuristic weight short name.
        /// </summary>
        public static readonly string HeuristicWeight = XmlPlannerCommand.GetOptionDependingOnPlattform("w");

        /// <summary>
        /// The inequality option short name.
        /// </summary>
        public static readonly string Inequality = XmlPlannerCommand.GetOptionDependingOnPlattform("i");

        /// <summary>
        /// The help option short name.
        /// </summary>
        public static readonly string Help = XmlPlannerCommand.PlattformHelpShortOption;

        /// <summary>
        /// The encoding option short name.
        /// </summary>
        public static readonly string Encoding = XmlPlannerCommand.GetOptionDependingOnPlattform("e");

        /// <summary>
        /// The verbose option short name.
        /// </summary>
        public static readonly string Verbose = XmlPlannerCommand.GetOptionDependingOnPlattform("v");

        /// <summary>
        /// The language option short name.
        /// </summary>
        public static readonly string Language = XmlPlannerCommand.GetOptionDependingOnPlattform("l");

        #endregion

    }

}
