/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.Globalization;

namespace Aran.Planning.Xml {

    /// <summary>
    /// Xpath management methods.
    /// </summary>
    [Serializable]
    internal static class XPathManager {

        #region Constants

        /// <summary>
        /// The xpath element separator.
        /// </summary>
        private const char ElementSeparator = '/';

        #endregion

        #region Methods

        /// <summary>
        /// Creates a new root xpath element.
        /// </summary>
        /// <param name="elementName">The element nam.</param>
        /// <returns>A new root xpath element.</returns>
        internal static string Create(string elementName) {
            return ElementSeparator + elementName;
        }

        /// <summary>
        /// Appends an element to an xpath.
        /// </summary>
        /// <param name="xpath">The xpath.</param>
        /// <param name="elementName">The element nam.</param>
        /// <returns>The result of appending <paramref name="elementName"/> to <paramref name="xpath"/>.</returns>
        internal static string Append(string xpath, string elementName) {
            return xpath + ElementSeparator + elementName;
        }

        /// <summary>
        /// Appends an element position to an xpath.
        /// </summary>
        /// <param name="xpath">The xpath.</param>
        /// <param name="elementName">The element name.</param>
        /// <param name="position">The element position.</param>
        /// <returns>The result of appending <paramref name="elementName"/> and <paramref name="position"/> to
        /// <paramref name="xpath"/>.</returns>
        internal static string Append(string xpath, string elementName, int position) {
            const string PositionedElementFormat = "{0}/{1}[position()='{2}']";
            return String.Format(CultureInfo.InvariantCulture, PositionedElementFormat, xpath,
                elementName, position + 1);
        }
        /// <summary>
        /// Appends a subelement position to an xpath.
        /// </summary>
        /// <param name="xpath">The xpath.</param>
        /// <param name="elementName">The element name.</param>
        /// <param name="subelementName">The subelement name.</param>
        /// <param name="position">The subelement position.</param>
        /// <returns>The result of appending <paramref name="elementName"/>, <paramref name="subelementName"/>
        /// and <paramref name="position"/> to <paramref name="xpath"/>.</returns>
        internal static string Append(string xpath, string elementName, string subelementName, int position) {
            const string PositionedElementFormat = "{0}/{1}/{2}[position()='{3}']";
            return String.Format(CultureInfo.InvariantCulture, PositionedElementFormat, xpath,
                elementName, subelementName, position + 1);
        }

        #endregion

    }

}
