/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.IO;
using System.Xml;
using System.Text;

using Aran.Representation;
using Aran.Representation.Xml;
using Aran.Translation;

namespace Aran.Planning.Xml {

    /// <summary>
    /// Represents a <see cref="XmlPlanner">planner</see> output plan XML doument writer.
    /// </summary>
    internal sealed class XmlPlanWriter {

        #region Fields

        /// <summary>
        /// The underlying writer.
        /// </summary>
        private readonly XmlWriter _writer;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="XmlPlanWriter"/> class.
        /// </summary>
        /// <param name="stream">The stream to write.</param>
        /// <param name="encoding">The encoding.</param>
        internal XmlPlanWriter(Stream stream, Encoding encoding) {
            //create the underlying writer
            XmlWriterSettings settings = new XmlWriterSettings();
            settings.CloseOutput = true;
            settings.Encoding = encoding;
            settings.Indent = true;
            settings.IndentChars = "  ";
            _writer = XmlWriter.Create(stream, settings);
            //write XML elements until the action list section
            _writer.WriteStartDocument(true);
            _writer.WriteStartElement(XmlElementName.Definition);
            _writer.WriteStartElement(XmlPlanElementName.Plan);
        }

        #endregion

        #region Methods

        /// <summary>
        /// Writes the specified action.
        /// </summary>
        /// <param name="action">The action.</param>
        internal void Write(IInstance<string, string> action) {
            //write the operator name
            string operatorName = action.SignatureId;
            _writer.WriteStartElement(XmlPlanElementName.Action);
            _writer.WriteAttributeString(XmlPlanAttributeName.Operator, operatorName);
            //for each argument name
            foreach (string objectName in action.GetArgumentIds()) {
                //write the argument element
                _writer.WriteStartElement(XmlElementName.Object);
                _writer.WriteAttributeString(XmlPlanAttributeName.Name, objectName);
                _writer.WriteEndElement();
            }
            _writer.WriteEndElement();
        }

        /// <summary>
        /// Closes the writer.
        /// </summary>
        internal void Close() {
            _writer.WriteEndDocument();
            _writer.Close();
        }

        #endregion

    }

}