/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.Text;

namespace Aran.Planning.Xml {

    /// <summary>
    /// Represents a <see cref="XmlPlanner">planner</see> default configuration value.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public static class XmlPlannerDefaultValue {

        #region Constants

        /// <summary>
        /// The default <see cref="XmlPlanner.DomainPath">domain XML input document path</see>.
        /// </summary>
        public const string DomainPath = "domain.xml";

        /// <summary>
        /// The default <see cref="XmlPlanner.ProblemPath">problem XML input document path</see>.
        /// </summary>
        public const string ProblemPath = "problem.xml";

        /// <summary>
        /// The default <see cref="XmlPlanner.OutputPath">plan XML output document path</see>.
        /// </summary>
        public const string OutputPath = "plan.xml";

        /// <summary>
        /// The default <see cref="XmlPlanner.OutputEncodingSource">plan XML output document
        /// encoding</see> source.
        /// </summary>
        public const XmlPlannerOutputEncodingSource OutputEncodingSource = XmlPlannerOutputEncodingSource.Problem;

        /// <summary>
        /// The default <see cref="XmlPlanner.OutputEncoding">plan XML output document custom
        /// encoding</see>.
        /// </summary>
        public static readonly Encoding OutputEncoding = Encoding.UTF8;

        /// <summary>
        /// The default <see cref="XmlPlanner.OverwriteOutput">plan XML output document overwriting
        /// decision</see>.
        /// </summary>
        public const bool OverwriteOutput = true;

        /// <summary>
        /// The default <see cref="XmlPlanner.MaxTimeEnabled">maximum planning time consideration
        /// decision</see>.
        /// </summary>
        public const bool MaxTimeEnabled = false;

        /// <summary>
        /// The default <see cref="XmlPlanner.MaxTime">maximum planning time</see>.
        /// </summary>
        public const long MaxTime = XmlPlannerMinimumValue.MaxTime;

        /// <summary>
        /// The default <see cref="XmlPlanner.MaxPlanLengthEnabled">maximum plan length consideration
        /// decision</see>.
        /// </summary>
        public const bool MaxPlanLengthEnabled = false;

        /// <summary>
        /// The default <see cref="XmlPlanner.MaxPlanLength">maximum plan length</see>.
        /// </summary>
        public const int MaxPlanLength = XmlPlannerMinimumValue.MaxPlanLength;

        /// <summary>
        /// The default <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> contained into
        /// <see cref="XmlPlanner.SearchAlgorithms">the sequence to be executed until a plan is
        /// found</see>.
        /// </summary>
        private static readonly XmlPlannerSearchAlgorithm _searchAlgorithm =
            XmlPlannerSearchAlgorithm.Create(XmlPlannerSearchAlgorithmId.AStar);

        /// <summary>
        /// The default <see cref="XmlPlanner.RootTypeEnabled">root type consideration decision</see>.
        /// </summary>
        public const bool RootTypeEnabled = false;

        /// <summary>
        /// The default <see cref="XmlPlanner.RootType">the domain root type</see>.
        /// </summary>
        public const string RootType = "object";

        /// <summary>
        /// The default <see cref="XmlPlanner.InequalitiesEnabled">predicate inequalities
        /// consideration decision</see>.
        /// </summary>
        public const bool InequalitiesEnabled = false;

        #endregion

        #region Properties


        /// <summary>
        /// Gets the default <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> contained into
        /// <see cref="XmlPlanner.SearchAlgorithms">the sequence to be executed until a plan is found</see>.
        /// </summary>
        /// <value>A copy of the default <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> contained
        /// into <see cref="XmlPlanner.SearchAlgorithms">the sequence to be executed until a plan is
        /// found</see>.</value>
        public static XmlPlannerSearchAlgorithm SearchAlgorithm {
            get {
                return _searchAlgorithm.Clone();
            }
        }

        #endregion

    }

}
