/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

using Aran.Core;
using Aran.Translation;
using Aran.Searching.Specialized;
using Aran.Searching;

namespace Aran.Planning.Xml {

    /// <summary>
    /// Represents a search algorithm with common parameters.
    /// </summary>
    [Serializable]
    internal abstract class XmlPlannerGenericSearchAlgorithm : XmlPlannerSearchAlgorithm {

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="XmlPlannerGenericSearchAlgorithm"/> class.
        /// </summary>
        /// <param name="resources">The resource manager.</param>
        internal XmlPlannerGenericSearchAlgorithm(Resources resources)
            : base(resources) {
        }

        #endregion

        #region Methods

        /// <summary>
        /// Creates the search algorithm.
        /// </summary>
        /// <param name="planner">The planner.</param>
        /// <param name="translationResult">The translation result.</param>
        /// <param name="initialStateProvider">The initial state provider.</param>
        /// <param name="goalVerifier">The goal verifier.</param>
        /// <param name="successorsGenerator">The successors generator.</param>
        /// <param name="costCalculator">The cost calculator.</param>
        /// <param name="heuristicCalculator">The heuristic calculator.</param>
        /// <returns>The search algorithm</returns>
        protected internal abstract ISearchAlgorithm<State> CreateSearchAlgorithm(XmlPlanner planner,
        TranslationResult<string, string, string, string, string, string, string> translationResult,
        IInitialStateProvider<State> initialStateProvider, IGoalStateVerifier<State> goalVerifier,
        IStateSuccessorsProvider<State> successorsGenerator, IStateCostProvider<State> costCalculator,
        IStateHeuristicCostProvider<State> heuristicCalculator);

        /// <summary>
        /// Creates the search algorithm.
        /// </summary>
        /// <param name="planner">The planner.</param>
        /// <param name="translationResult">The translation result.</param>
        /// <returns>The search algorithm.</returns>
        internal override ISearchAlgorithm<State> CreateSearchAlgorithm(XmlPlanner planner,
        TranslationResult<string, string, string, string, string, string, string> translationResult) {
            IInitialStateProvider<State> initialStateProvider = CreateInitialStateProvider(translationResult);
            IGoalStateVerifier<State> goalVerifier = CreateGoalStateVerifier(planner, translationResult);
            IStateSuccessorsProvider<State> successorsGenerator = CreateSuccessorsGenerator(translationResult);
            IStateCostProvider<State> costCalculator = CreateStateCostProvider(translationResult);
            IStateHeuristicCostProvider<State> heuristicCalculator =
                CreateHeuristicCalculator(translationResult, costCalculator);
            return CreateSearchAlgorithm(planner, translationResult, initialStateProvider, goalVerifier,
                successorsGenerator, costCalculator, heuristicCalculator);
        }

        #endregion

    }

}
