/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

using Aran.Translation;

namespace Aran.Planning.Xml {

    /// <summary>
    /// <para>Represents a <see cref="XmlPlanner">planner</see> predicate inequality.</para>
    /// <para>Predicate inequalities are special predicates which cause the
    /// <see cref="XmlPlanner">planner</see> to automatically define them, without being writen in
    /// input documents, and generate a fact for each couple of objects of the type defined in the inequality
    /// if both objects are not the same.</para>
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public class XmlPlannerInequality {

        #region Fields

        /// <summary>
        /// The internal inequality predicate.
        /// </summary>
        private readonly InequalityPredicate<string, string> _predicate;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="XmlPlannerInequality"/> class.
        /// </summary>
        /// <param name="predicate">The internal inequality predicate.</param>
        internal XmlPlannerInequality(InequalityPredicate<string, string> predicate) {
            _predicate = predicate;
        }

        #endregion

        #region Properties

        /// <summary>
        /// Gets the predicate name.
        /// </summary>
        /// <value>The predicate name.</value>
        public string Predicate {
            get {
                return _predicate.PredicateId;
            }
        }

        /// <summary>
        /// Gets the type name of the objects being affected by the inequality.
        /// </summary>
        /// <value>The type name of the objects being affected by the inequality.</value>
        public string Type {
            get {
                return _predicate.TypeId;
            }
        }

        #endregion

    }

}
