/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Planning.Xml {

    /// <summary>
    /// Represents a <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> identifier.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public enum XmlPlannerSearchAlgorithmId {

        #region Fields

        /// <summary>
        /// The A* algorithm identifier.
        /// </summary>
        AStar,

        /// <summary>
        /// The Beam Search algorithm identifier.
        /// </summary>
        BeamSearch,

        /// <summary>
        /// The Dijkstra algorithm identifier.
        /// </summary>
        Dijkstra,

        /// <summary>
        /// The Enforced Hill Climbing algorithm identifier.
        /// </summary>
        EnforcedHillClimbing,

        /// <summary>
        /// The Hill Climbing algorithm identifier.
        /// </summary>
        HillClimbing,

        /// <summary>
        /// The Weighted A* algorithm identifier.
        /// </summary>
        WeightedAStar

        #endregion

    }

}
