/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Planning.Xml {

    /// <summary>
    /// Represents the arguments of an event which occurs when a
    /// <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> is selected by the
    /// <see cref="XmlPlanner">planner</see> to be executed.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class XmlPlannerSearchAlgorithmSelectedEventArgs : EventArgs {

        #region Fields

        /// <summary>
        /// The <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> selected by the
        /// <see cref="XmlPlanner">planner</see> to be executed.
        /// </summary>
        private readonly XmlPlannerSearchAlgorithm _searchAlgorithm;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="XmlPlannerSearchAlgorithmSelectedEventArgs"/> class.
        /// </summary>
        /// <param name="searchAlgorithm">The <see cref="XmlPlannerSearchAlgorithm">search algorithm</see>
        /// selected by the <see cref="XmlPlanner">planner</see> to be executed.</param>
        internal XmlPlannerSearchAlgorithmSelectedEventArgs(XmlPlannerSearchAlgorithm searchAlgorithm) {
            _searchAlgorithm = searchAlgorithm;
        }

        #endregion

        #region Properties

        /// <summary>
        /// Gets the <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> selected by the
        /// <see cref="XmlPlanner">planner</see> to be executed.
        /// </summary>
        /// <value>The <see cref="XmlPlannerSearchAlgorithm">search algorithm</see> selected by the
        /// <see cref="XmlPlanner">planner</see> to be executed.</value>
        public XmlPlannerSearchAlgorithm SearchAlgorithm {
            get {
                return _searchAlgorithm;
            }
        }

        #endregion

    }

}
