/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.Xml.Schema;
using System.Xml.Serialization;
using System.Collections.Generic;

namespace Aran.Representation.Xml.Internal {

    /// <summary>
    /// <para>This class supports the parser infrastructure and is not intended to be used directly from your code.</para>
    /// <para>Represents a fact declaration defined within an XML input document.</para>
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    [XmlType(TypeName = XmlTypeName.FactDeclaration)]
    public class InternalFactDeclaration {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        #region Fields

        /// <summary>
        /// The predicate name.
        /// </summary>
        [XmlAttribute(AttributeName = XmlAttributeName.Predicate, Form = XmlSchemaForm.Unqualified, DataType = XmlDataType.String)]
        public string Predicate;

        /// <summary>
        /// The name.
        /// </summary>
        [XmlAttribute(AttributeName = XmlAttributeName.Name, Form = XmlSchemaForm.Unqualified, DataType = XmlDataType.String)]
        public string Name;

        /// <summary>
        /// The arguments.
        /// </summary>
        [XmlElement(Type = typeof(InternalNamed), ElementName = XmlElementName.Object, IsNullable = false, Form = XmlSchemaForm.Unqualified)]
        public List<InternalNamed> Arguments;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="InternalFactDeclaration"/> class.
        /// </summary>
        public InternalFactDeclaration() {
            Arguments = new List<InternalNamed>();
        }

        #endregion

    }
	
}
