/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.Xml.Schema;
using System.Xml.Serialization;

namespace Aran.Representation.Xml.Internal {

    /// <summary>
    /// <para>This class supports the parser infrastructure and is not intended to be used directly from your code.</para>
    /// <para>Represents an operation symbol defined within an XML input document.</para>
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public enum InternalOperationSymbol {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        /// <summary>
        /// The assignment (=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Assignment)]
        Assignment,

        /// <summary>
        /// The sum assignment (+=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.SumAssignment)]
        SumAssignment,

        /// <summary>
        /// The subtraction assignment (-=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.SubtractionAssignment)]
        SubtractionAssignment,

        /// <summary>
        /// The multiplication assignment (*=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.MultiplicationAssignment)]
        MultiplicationAssignment,

        /// <summary>
        /// The division assignment (/=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.DivisionAssignment)]
        DivisionAssignment,

        /// <summary>
        /// The sum (+) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Sum)]
        Sum,

        /// <summary>
        /// The subtraction (-) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Subtraction)]
        Subtraction,

        /// <summary>
        /// The multiplication (*) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Multiplication)]
        Multiplication,

        /// <summary>
        /// The division (/) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Division)]
        Division,

        /// <summary>
        /// The inferiority (&lt;) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Inferiority)]
        Inferiority,

        /// <summary>
        /// The non-superiority (&lt;=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.NonSuperiority)]
        NonSuperiority,

        /// <summary>
        /// The equality (==) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Equality)]
        Equality,

        /// <summary>
        /// The inequality (!=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Inequality)]
        Inequality,

        /// <summary>
        /// The non-inferiority (>=) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.NonInferiority)]
        NonInferiority,

        /// <summary>
        /// The superiority (>) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Superiority)]
        Superiority,

        /// <summary>
        /// The conjunction (&amp;&amp;) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Conjunction)]
        Conjunction,

        /// <summary>
        /// The disjunction (||) operation symbol.
        /// </summary>
        [XmlEnum(Name = XmlOperationSymbol.Disjunction)]
        Disjunction
    }
	
}
