/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.Resources;
using System.Globalization;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents the resources for this namespace classes.
    /// </summary>
    [Serializable]
    internal sealed class Resources {

        #region Fields

        /// <summary>
        /// The underlying resource manager.
        /// </summary>
        private readonly ResourceManager _resources;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="Resources"/> class.
        /// </summary>
        internal Resources() {
            _resources = new ResourceManager(GetType());
        }

        #endregion

        #region Properties

        /// <summary>
        /// Gets the culture.
        /// </summary>
        /// <value>The culture.</value>
        private static CultureInfo Culture {
            get {
                return CultureInfo.CurrentUICulture;
            }
        }

        /// <summary>
        /// Gets the "no domain stream set" message.
        /// </summary>
        /// <value>The "no domain stream set" message.</value>
        internal string NoDomainStreamSet {
            get {
                return _resources.GetString("NoDomainStreamSet", Culture);
            }
        }

        /// <summary>
        /// Gets the "no problem stream set" message.
        /// </summary>
        /// <value>The "no problem stream set" message.</value>
        internal string NoProblemStreamSet {
            get {
                return _resources.GetString("NoProblemStreamSet", Culture);
            }
        }

        /// <summary>
        /// Gets the "no domain found" message.
        /// </summary>
        /// <value>The "no domain found" message.</value>
        internal string NoDomainFound {
            get {
                return _resources.GetString("NoDomainFound", Culture);
            }
        }

        /// <summary>
        /// Gets the "no problem found" message.
        /// </summary>
        /// <value>The "no problem found" message.</value>
        internal string NoProblemFound {
            get {
                return _resources.GetString("NoProblemFound", Culture);
            }
        }

        /// <summary>
        /// Gets the "parsing errors found" message.
        /// </summary>
        /// <value>The "parsing errors found" message.</value>
        internal string ParsingErrorsFound {
            get {
                return _resources.GetString("ParsingErrorsFound", Culture);
            }
        }

        /// <summary>
        /// Gets the "domain mismatch found" message.
        /// </summary>
        /// <value>The "domain mismatch found" message.</value>
        internal string DomainMismatchFound {
            get {
                return _resources.GetString("DomainMismatchFound", Culture);
            }
        }

        #endregion

    }

}
