/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents an attribute name defined within an XML input document.
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public static class XmlAttributeName {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        #region Constants

        /// <summary>
        /// The name of the "name" attribute.
        /// </summary>
        public const string Name = "name";

        /// <summary>
        /// The name of the "domain" attribute.
        /// </summary>
        public const string Domain = "domain";

        /// <summary>
        /// The name of the "type" attribute.
        /// </summary>
        public const string Type = "type";

        /// <summary>
        /// The name of the "predicate" attribute.
        /// </summary>
        public const string Predicate = "predicate";

        /// <summary>
        /// The name of the "function" attribute.
        /// </summary>
        public const string Function = "function";

        /// <summary>
        /// The name of the "value" attribute.
        /// </summary>
        public const string Value = "value";

        /// <summary>
        /// The name of the "symbol" attribute.
        /// </summary>
        public const string Symbol = "symbol";

        /// <summary>
        /// The name of the "parent" attribute.
        /// </summary>
        public const string Parent = "parent";

        #endregion

    }

}
