/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.Runtime.Serialization;

namespace Aran.Representation.Xml {

	/// <summary>
	/// Represents an error occurred when the problem references a domain different from the provided one.
	/// </summary>
	[CLSCompliant(true)]
	[Serializable]
	public sealed class XmlDomainMismatchException : RepresentationException {

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the <see cref="XmlDomainMismatchException">XmlDomainMismatchException</see> class.
		/// </summary>
        /// <param name="message">The message that describes the error.</param>
		/// <remarks>
		/// <para>Initializes the <see cref="Exception.Message">Message</see> property of the new instance using
        /// the <paramref name="message"/> parameter.</para>
		/// <para>The following table shows the initial property values for an instance of
		/// <see cref="XmlDomainMismatchException">XmlDomainMismatchException</see>.</para>
		/// <list type="table">
		///    <listheader>
		///       <term>Property</term>
		///       <term>Value</term>
		///    </listheader>
		///    <item>
		///       <term>InnerException</term>
        ///       <description>A null reference.</description>
		///    </item>
        ///    <item>
        ///       <term>Message</term>
        ///       <description>The error message string.</description>
        ///    </item>
		/// </list>
		/// </remarks>
		internal XmlDomainMismatchException(string message)
            : base(message) {
		}

#if !XBOX360
        
        /// <summary>
        /// Initializes a new instance of the <see cref="XmlDomainMismatchException">XmlDomainMismatchException</see>
        /// class with serialized data.
        /// </summary>
        /// <param name="info">The serialized object data about the exception being thrown.</param>
        /// <param name="context">The contextual information about the source or destination.</param>
        /// <remarks>
        /// <para>This constructor is called during deserialization to reconstitute the exception object
        /// transmitted over a stream.</para>
        /// <para>This constructor is not available for the Xbox 360.</para>
        /// </remarks>
        /// <exception cref="ArgumentNullException">The <paramref name="info"/> parameter is a null reference.</exception>
        /// <exception cref="SerializationException">The class name is a null reference or
        /// <see cref="Exception.HResult">HResult</see> is zero (0).</exception>
        private XmlDomainMismatchException(SerializationInfo info, StreamingContext context)
            : base(info, context) {
        }

#endif

        #endregion

    }

}