/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents an element name defined within an XML input document.
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public static class XmlElementName {

        #region Constants

        /// <summary>
        /// The name of the "object" element.
        /// </summary>
        public const string Object = "object";

        /// <summary>
        /// The name of the "objects" element.
        /// </summary>
        public const string Objects = "objects";

        /// <summary>
        /// The name of the "fact" element.
        /// </summary>
        public const string Fact = "fact";

        /// <summary>
        /// The name of the "facts" element.
        /// </summary>
        public const string Facts = "facts";

        /// <summary>
        /// The name of the "variable" element.
        /// </summary>
        public const string Variable = "variable";

        /// <summary>
        /// The name of the "variables" element.
        /// </summary>
        public const string Variables = "variables";

        /// <summary>
        /// The name of the "constant" element.
        /// </summary>
        public const string Constant = "constant";

        /// <summary>
        /// The name of the "operation" element.
        /// </summary>
        public const string Operation = "operation";

        /// <summary>
        /// The name of the "operand" element.
        /// </summary>
        public const string Operand = "operand";

        /// <summary>
        /// The name of the "type" element.
        /// </summary>
        public const string Type = "type";

        /// <summary>
        /// The name of the "parameter" element.
        /// </summary>
        public const string Parameter = "parameter";

        /// <summary>
        /// The name of the "parameters" element.
        /// </summary>
        public const string Parameters = "parameters";

        /// <summary>
        /// The name of the "predicate" element.
        /// </summary>
        public const string Predicate = "predicate";

        /// <summary>
        /// The name of the "function" element.
        /// </summary>
        public const string Function = "function";

        /// <summary>
        /// The name of the "preconditions" element.
        /// </summary>
        public const string Preconditions = "preconditions";

        /// <summary>
        /// The name of the "functionalPreconditions" element.
        /// </summary>
        public const string FunctionalPreconditions = "functionalPreconditions";

        /// <summary>
        /// The name of the "deletions" element.
        /// </summary>
        public const string Deletions = "deletions";

        /// <summary>
        /// The name of the "additions" element.
        /// </summary>
        public const string Additions = "additions";

        /// <summary>
        /// The name of the "functionalEffects" element.
        /// </summary>
        public const string FunctionalEffects = "functionalEffects";

        /// <summary>
        /// The name of the "operator" element.
        /// </summary>
        public const string Operator = "operator";

        /// <summary>
        /// The name of the "target" element.
        /// </summary>
        public const string Target = "target";

        /// <summary>
        /// The name of the "initialFacts" element.
        /// </summary>
        public const string InitialFacts = "initialFacts";

        /// <summary>
        /// The name of the "functionalInitializations" element.
        /// </summary>
        public const string FunctionalInitializations = "functionalInitializations";

        /// <summary>
        /// The name of the "goalFacts" element.
        /// </summary>
        public const string GoalFacts = "goalFacts";

        /// <summary>
        /// The name of the "functionalGoals" element.
        /// </summary>
        public const string FunctionalGoals = "functionalGoals";

        /// <summary>
        /// The name of the "metric" element.
        /// </summary>
        public const string Metric = "metric";

        /// <summary>
        /// The name of the "domain" element.
        /// </summary>
        public const string Domain = "domain";

        /// <summary>
        /// The name of the "types" element.
        /// </summary>
        public const string Types = "types";

        /// <summary>
        /// The name of the "predicates" element.
        /// </summary>
        public const string Predicates = "predicates";

        /// <summary>
        /// The name of the "functions" element.
        /// </summary>
        public const string Functions = "functions";

        /// <summary>
        /// The name of the "operators" element.
        /// </summary>
        public const string Operators = "operators";

        /// <summary>
        /// The name of the "definition" element.
        /// </summary>
        public const string Definition = "definition";

        /// <summary>
        /// The name of the "problem" element.
        /// </summary>
        public const string Problem = "problem";

        #endregion

    }

}
