/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents a knowledge representation defined within XML input documents.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class XmlKnowledge : IKnowledge<string, string, string, string, string, string, string> {

        #region Fields

        /// <summary>
        /// The domain.
        /// </summary>
        private XmlDomain _domain;

        /// <summary>
        /// The problem.
        /// </summary>
        private XmlProblem _problem;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="XmlKnowledge"/> class.
        /// </summary>
        /// <param name="domain">The domain.</param>
        /// <param name="problem">The problem.</param>
        public XmlKnowledge(XmlDomain domain, XmlProblem problem) {
            _domain = domain;
            _problem = problem;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Gets the domain.
        /// </summary>
        /// <value>The domain.</value>
        /// <remarks>A full-retrieved result is not ensured. More on-demand retrieving tasks could be done, depending
        /// on implementation details, while managing the returned result components.</remarks>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        public IDomain<string, string, string, string, string, string, string> GetDomain() {
            return _domain;
        }

        /// <summary>
        /// Gets the problem.
        /// </summary>
        /// <value>The problem.</value>
        /// <remarks>A full-retrieved result is not ensured. More on-demand retrieving tasks could be done, depending
        /// on implementation details, while managing the returned result components.</remarks>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        public IProblem<string, string, string, string, string, string, string> GetProblem() {
            return _problem;
        }

        #endregion

    }

}
