/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

using Aran.Representation.Xml.Internal;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents a converter between a metric type defined within an XML input document and the values defined in
    /// the <see cref="MetricType">generic metric type</see>.
    /// </summary>
    [Serializable]
    internal static class XmlMetricTypeConverter {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        #region Methods

        /// <summary>
        /// Gets a <see cref="MetricType">generic metric type</see> value from an XML one.
        /// </summary>
        /// <param name="metricType">The XML metric type value.</param>
        /// <returns>The <see cref="MetricType">generic metric type</see> which corresponds to
        /// <paramref name="metricType"/>.</returns>
        internal static MetricType FromXml(InternalMetricType metricType) {
            switch (metricType) {
                case InternalMetricType.Minimization:
                    return MetricType.Minimization;
                case InternalMetricType.Maximization:
                    return MetricType.Maximization;
            }
            return MetricType.Minimization;
        }

        #endregion

    }

}
