/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

using Aran.Representation.Xml.Internal;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents an object defined within an XML input document.
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public sealed class XmlObject : XmlLocatable, IObject<string, string> {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        #region Fields

        /// <summary>
        /// The internal object representacion.
        /// </summary>
        private readonly InternalObjectDeclaration _object;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="XmlObject"/> class.
        /// </summary>
        /// <param name="xpath">The xpath.</param>
        /// <param name="obj">The internal object representacion.</param>
        internal XmlObject(string xpath, InternalObjectDeclaration obj)
            : base(xpath) {
            _object = obj;
        }

        #endregion

        #region Properties

        /// <summary>
        /// Gets the identifier.
        /// </summary>
        /// <value>The identifier.</value>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        public string Id {
            get {
                return _object.Name;
            }
        }

        /// <summary>
        /// Gets the type identifier.
        /// </summary>
        /// <value>The type identifier.</value>
        /// <remarks>The identifier must refer to a type returned by
        /// <see cref="IDomain{TType, TPred, TFunc, TOp, TObj, TFact, TVar}.GetTypes">the domain
        /// corresponding method</see>.</remarks>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        public string TypeId {
            get {
                return _object.Type;
            }
        }

        #endregion

    }

}
