/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents an operation symbol defined within an XML input document.
    /// </summary>
    [Serializable]
    [CLSCompliant(true)]
    public static class XmlOperationSymbol {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        #region Constants

        /// <summary>
        /// The assignment (=) operation symbol.
        /// </summary>
        public const string Assignment = "=";

        /// <summary>
        /// The sum assignment (+=) operation symbol.
        /// </summary>
        public const string SumAssignment = "+=";

        /// <summary>
        /// The subtraction assignment (-=) operation symbol.
        /// </summary>
        public const string SubtractionAssignment = "-=";

        /// <summary>
        /// The multiplication assignment (*=) operation symbol.
        /// </summary>
        public const string MultiplicationAssignment = "*=";

        /// <summary>
        /// The division assignment (/=) operation symbol.
        /// </summary>
        public const string DivisionAssignment = "/=";

        /// <summary>
        /// The sum (+) operation symbol.
        /// </summary>
        public const string Sum = "+";

        /// <summary>
        /// The subtraction (-) operation symbol.
        /// </summary>
        public const string Subtraction = "-";

        /// <summary>
        /// The multiplication (*) operation symbol.
        /// </summary>
        public const string Multiplication = "*";

        /// <summary>
        /// The division (/) operation symbol.
        /// </summary>
        public const string Division = "/";

        /// <summary>
        /// The inferiority (&lt;) operation symbol.
        /// </summary>
        public const string Inferiority = "lt";

        /// <summary>
        /// The non-superiority (&lt;=) operation symbol.
        /// </summary>
        public const string NonSuperiority = "lt=";

        /// <summary>
        /// The equality (==) operation symbol.
        /// </summary>
        public const string Equality = "==";

        /// <summary>
        /// The inequality (!=) operation symbol.
        /// </summary>
        public const string Inequality = "!=";

        /// <summary>
        /// The non-inferiority (>=) operation symbol.
        /// </summary>
        public const string NonInferiority = "gt=";

        /// <summary>
        /// The superiority (>) operation symbol.
        /// </summary>
        public const string Superiority = "gt";

        /// <summary>
        /// The conjunction (&amp;&amp;) operation symbol.
        /// </summary>
        public const string Conjunction = "and";

        /// <summary>
        /// The disjunction (||) operation symbol.
        /// </summary>
        public const string Disjunction = "or";

        #endregion

    }

}
