/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

using Aran.Representation.Xml.Internal;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents a converter between an operation symbol defined within an XML input document and the values defined
    /// in the <see cref="OperationType">generic operation type</see>.
    /// </summary>
    [Serializable]
    internal static class XmlOperationTypeConverter {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        #region Methods

        /// <summary>
        /// Gets a <see cref="OperationType">generic operation type</see> value from an XML operation symbol.
        /// </summary>
        /// <param name="operationSymbol">The XML operation symbol.</param>
        /// <returns>The <see cref="MetricType">generic operation type</see> which corresponds to
        /// <paramref name="operationSymbol"/>.</returns>
        internal static OperationType FromXml(InternalOperationSymbol operationSymbol) {
            switch (operationSymbol) {
                case InternalOperationSymbol.Assignment:
                    return OperationType.Assignment;
                case InternalOperationSymbol.SumAssignment:
                    return OperationType.SumAssignment;
                case InternalOperationSymbol.SubtractionAssignment:
                    return OperationType.SubtractionAssignment;
                case InternalOperationSymbol.MultiplicationAssignment:
                    return OperationType.MultiplicationAssignment;
                case InternalOperationSymbol.DivisionAssignment:
                    return OperationType.DivisionAssignment;
                case InternalOperationSymbol.Sum:
                    return OperationType.Sum;
                case InternalOperationSymbol.Subtraction:
                    return OperationType.Subtraction;
                case InternalOperationSymbol.Multiplication:
                    return OperationType.Multiplication;
                case InternalOperationSymbol.Division:
                    return OperationType.Division;
                case InternalOperationSymbol.Inferiority:
                    return OperationType.Inferiority;
                case InternalOperationSymbol.NonSuperiority:
                    return OperationType.NonSuperiority;
                case InternalOperationSymbol.Equality:
                    return OperationType.Equality;
                case InternalOperationSymbol.Inequality:
                    return OperationType.Inequality;
                case InternalOperationSymbol.NonInferiority:
                    return OperationType.NonInferiority;
                case InternalOperationSymbol.Superiority:
                    return OperationType.Superiority;
                case InternalOperationSymbol.Conjunction:
                    return OperationType.Conjunction;
                case InternalOperationSymbol.Disjunction:
                    return OperationType.Disjunction;
	        }
            return OperationType.Assignment;
        }

        #endregion

    }

}
