/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation.Xml {

	/// <summary>
	/// Represents an error occurred when no problem is found.
	/// </summary>
	[CLSCompliant(true)]
	[Serializable]
    public sealed class XmlProblemNotFoundException : RepresentationException {

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the <see cref="XmlProblemNotFoundException">XmlProblemNotFoundException</see> class.
		/// </summary>
        /// <param name="message">The message that describes the error.</param>
		/// <remarks>
		/// <para>Initializes the <see cref="Exception.Message">Message</see> property of the new instance using
        /// the <paramref name="message"/> parameter.</para>
		/// <para>The following table shows the initial property values for an instance of
		/// <see cref="XmlProblemNotFoundException">XmlProblemNotFoundException</see>.</para>
		/// <list type="table">
		///    <listheader>
		///       <term>Property</term>
		///       <term>Value</term>
		///    </listheader>
		///    <item>
		///       <term>InnerException</term>
        ///       <description>A null reference.</description>
		///    </item>
        ///    <item>
        ///       <term>Message</term>
        ///       <description>The error message string.</description>
        ///    </item>
		/// </list>
		/// </remarks>
		internal XmlProblemNotFoundException(string message)
            : base(message) {
		}

		#endregion

	}

}