/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation.Xml {

    /// <summary>
    /// Represents a type name defined within an XML input document.
    /// </summary>
    [Serializable]
    internal static class XmlTypeName {

        /*
         * NOTE: This type and all of the same namespace have been designed for being functional, but not
         * efficient, neither in memory consumption nor in time taken. So, in that way, the current
         * implementation of this parser is highly improvable. For example, a future implementation may use its
         * own parsing routines, instead of using the .NET built-in XML serialization ones.
         */

        #region Constants

        /// <summary>
        /// The "named" type.
        /// </summary>
        public const string Named = "named";

        /// <summary>
        /// The "objectDeclaration" type.
        /// </summary>
        public const string ObjectDeclaration = "objectDeclaration";

        /// <summary>
        /// The "objectDeclarationList" type.
        /// </summary>
        public const string ObjectDeclarationList = "objectDeclarationList";

        /// <summary>
        /// The "factList" type.
        /// </summary>
        public const string FactList = "factList";

        /// <summary>
        /// The "factDeclaration" type.
        /// </summary>
        public const string FactDeclaration = "factDeclaration";

        /// <summary>
        /// The "factDeclarationList" type.
        /// </summary>
        public const string FactDeclarationList = "factDeclarationList";

        /// <summary>
        /// The "variableDeclaration" type.
        /// </summary>
        public const string VariableDeclaration = "variableDeclaration";

        /// <summary>
        /// The "variableDeclarationList" type.
        /// </summary>
        public const string VariableDeclarationList = "variableDeclarationList";

        /// <summary>
        /// The "constant" type.
        /// </summary>
        public const string Constant = "constant";

        /// <summary>
        /// The "operand" type.
        /// </summary>
        public const string Operand = "operand";

        /// <summary>
        /// The "operation" type.
        /// </summary>
        public const string Operation = "operation";

        /// <summary>
        /// The "operationList" type.
        /// </summary>
        public const string OperationList = "operationList";

        /// <summary>
        /// The "typeDeclaration" type.
        /// </summary>
        public const string TypeDeclaration = "typeDeclaration";

        /// <summary>
        /// The "typeDeclarationList" type.
        /// </summary>
        public const string TypeDeclarationList = "typeDeclarationList";

        /// <summary>
        /// The "signature" type.
        /// </summary>
        public const string Signature = "signature";

        /// <summary>
        /// The "predicateList" type.
        /// </summary>
        public const string PredicateList = "predicateList";

        /// <summary>
        /// The "functionList" type.
        /// </summary>
        public const string FunctionList = "functionList";

        /// <summary>
        /// The "operator" type.
        /// </summary>
        public const string Operator = "operator";

        /// <summary>
        /// The "operatorList" type.
        /// </summary>
        public const string OperatorList = "operatorList";

        /// <summary>
        /// The "metric" type.
        /// </summary>
        public const string Metric = "metric";

        /// <summary>
        /// The "problem" type.
        /// </summary>
        public const string Problem = "problem";

        /// <summary>
        /// The "domain" type.
        /// </summary>
        public const string Domain = "domain";

        #endregion

    }

}
