/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation {

    /// <summary>
    /// Represents an <see cref="Object">object</see> capable of providing a knowledge representation.
    /// </summary>
    /// <typeparam name="TType">The type of the type identifiers.</typeparam>
    /// <typeparam name="TPred">The type of the predicate identifiers.</typeparam>
    /// <typeparam name="TFunc">The type of the function identifiers.</typeparam>
    /// <typeparam name="TOp">The type of the operator identifiers.</typeparam>
    /// <typeparam name="TObj">The type of the object identifiers.</typeparam>
    /// <typeparam name="TFact">The type of the fact identifiers.</typeparam>
    /// <typeparam name="TVar">The type of the variable identifiers.</typeparam>
    [CLSCompliant(true)]
    public interface IKnowledgeProvider<TType, TPred, TFunc, TOp, TObj, TFact, TVar> {

        #region Methods

        /// <summary>
        /// Gets the knowledge representation.
        /// </summary>
        /// <returns>The knowledge representation.</returns>
        /// <para>A full-retrieved result is not ensured. More on-demand retrieving tasks could be done, depending on
        /// implementation details, while managing the returned result components.</para>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        IKnowledge<TType, TPred, TFunc, TOp, TObj, TFact, TVar> GetKnowledge();

        #endregion

    }

}