/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation {

    /// <summary>
    /// Represents a metric.
    /// </summary>
    /// <remarks>
    /// The metric may not be full-retrieved. More on-demand retrieving tasks could be done, depending on
    /// implementation details, while managing its components.
    /// </remarks>
    /// <typeparam name="T">The type of the variable identifiers.</typeparam>
    [CLSCompliant(true)]
    public interface IMetric<T> {

        #region Properties

        /// <summary>
        /// Gets the type.
        /// </summary>
        /// <value>The type.</value>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        MetricType Type { get; }

        #endregion

        #region Methods

        /// <summary>
        /// Gets the target.
        /// </summary>
        /// <returns>The target.</returns>
        /// <remarks>
        /// <para>All target variable identifiers must refer to variables returned by 
        /// <see cref="IProblem{TType, TPred, TFunc, TOp, TObj, TFact, TVar}.GetVariables">the problem
        /// corresponding method</see>.</para>
        /// <para>A full-retrieved result is not ensured. More on-demand retrieving tasks could be done, depending
        /// on implementation details, while managing the returned result components.</para>
        /// </remarks>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        IOperand<T> GetTarget();

        #endregion

    }

}
