/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation {

    /// <summary>
    /// Represents an object.
    /// </summary>
    /// <remarks>
    /// The object may not be full-retrieved. More on-demand retrieving tasks could be done, depending on
    /// implementation details, while managing its components.
    /// </remarks>
    /// <typeparam name="TType">The type of the type identifier.</typeparam>
    /// <typeparam name="TObj">The type of the object identifier.</typeparam>
    [CLSCompliant(true)]
    public interface IObject<TType, TObj> : IIdentified<TObj> {

        #region Properties

        /// <summary>
        /// Gets the type identifier.
        /// </summary>
        /// <value>The type identifier.</value>
        /// <remarks>The identifier must refer to a type returned by
        /// <see cref="IDomain{TType, TPred, TFunc, TOp, TObj, TFact, TVar}.GetTypes">the domain
        /// corresponding method</see>.</remarks>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        TType TypeId { get; }

        #endregion

    }

}
