/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation {

    /// <summary>
    /// Represents an operand.
    /// </summary>
    /// <remarks>
    /// The operand may not be full-retrieved. More on-demand retrieving tasks could be done, depending on
    /// implementation details, while managing its components.
    /// </remarks>
    /// <typeparam name="T">The type of the variable identifiers.</typeparam>
    [CLSCompliant(true)]
    public interface IOperand<T> {

        #region Properties

        /// <summary>
        /// Gets the type.
        /// </summary>
        /// <value>The type.</value>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        OperandType Type { get; }

        /// <summary>
        /// Gets the variable identifier.
        /// </summary>
        /// <value>The variable identifier.</value>
        /// <exception cref="InvalidOperationException">the <see cref="Type">type</see> is not
        /// <see cref="OperandType.Variable">variable</see>.</exception>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        T VariableId { get; }

        /// <summary>
        /// Gets the constant value.
        /// </summary>
        /// <value>The constant value.</value>
        /// <exception cref="InvalidOperationException">the <see cref="Type">type</see> is not
        /// <see cref="OperandType.Constant">variable</see>.</exception>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        float ConstantValue { get; }

        /// <summary>
        /// Gets the operation.
        /// </summary>
        /// <value>The operation.</value>
        /// <exception cref="InvalidOperationException">the <see cref="Type">type</see> is not
        /// <see cref="OperandType.Operation">variable</see>.</exception>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        IOperation<T> Operation { get; }

        #endregion

    }

}
