/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation {

    /// <summary>
    /// Represents a type.
    /// </summary>
    /// <remarks>
    /// The type may not be full-retrieved. More on-demand retrieving tasks could be done, depending on
    /// implementation details, while managing its components.
    /// </remarks>
    /// <typeparam name="T">The type of the type identifier.</typeparam>
    [CLSCompliant(true)]
    public interface IType<T> : IIdentified<T> {

        #region Properties

        /// <summary>
        /// Determines if has no parent.
        /// </summary>
        /// <value>True if is root; otherwise, false.</value>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        bool IsRoot { get; }

        /// <summary>
        /// Gets the parent identifier.
        /// </summary>
        /// <value>The parent identifier.</value>
        /// <exception cref="InvalidOperationException">No metric is defined.</exception>
        /// <exception cref="RepresentationException">An error occurs while retrieving.</exception>
        T ParentId { get; }

        #endregion

    }

}
