/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Representation {

    /// <summary>
    /// Represents an operation type.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public enum OperationType {

        #region Fields

        /// <summary>
        /// Value which indicates that the operation is an assignment, like <c>a = b</c>.
        /// </summary>
        Assignment,

        /// <summary>
        /// Value which indicates that the operation is a sum assignment, like <c>a += b</c>.
        /// </summary>
        SumAssignment,

        /// <summary>
        /// Value which indicates that the operation is a subtraction assignment, like <c>a -= b</c>.
        /// </summary>
        SubtractionAssignment,

        /// <summary>
        /// Value which indicates that the operation is a multiplication assignment, like <c>a *= b</c>.
        /// </summary>
        MultiplicationAssignment,

        /// <summary>
        /// Value which indicates that the operation is a division assignment, like <c>a /= b</c>.
        /// </summary>
        DivisionAssignment,

        /// <summary>
        /// Value which indicates that the operation is a sum, like <c>a + b</c>.
        /// </summary>
        Sum,

        /// <summary>
        /// Value which indicates that the operation is a subtraction, like <c>a - b</c>.
        /// </summary>
        Subtraction,

        /// <summary>
        /// Value which indicates that the operation is a multiplication, like <c>a * b</c>.
        /// </summary>
        Multiplication,

        /// <summary>
        /// Value which indicates that the operation is a division, like <c>a / b</c>.
        /// </summary>
        Division,

        /// <summary>
        /// Value which indicates that the operation is an inferiority comparison, like <c>a &lt; b</c>.
        /// </summary>
        Inferiority,

        /// <summary>
        /// Value which indicates that the operation is a non-superiority comparison, like <c>a &lt;= b</c>.
        /// </summary>
        NonSuperiority,

        /// <summary>
        /// Value which indicates that the operation is an equality comparison, like <c>a == b</c>.
        /// </summary>
        Equality,

        /// <summary>
        /// Value which indicates that the operation is an inequality comparison, like <c>a != b</c>.
        /// </summary>
        Inequality,

        /// <summary>
        /// Value which indicates that the operation is a non-inferiority comparison, like <c>a >= b</c>.
        /// </summary>
        NonInferiority,

        /// <summary>
        /// Value which indicates that the operation is a superiority comparison, like <c>a > b</c>.
        /// </summary>
        Superiority,

        /// <summary>
        /// Value which indicates that the operation is a conjunction, like <c>a &amp;&amp; b</c>.
        /// </summary>
        Conjunction,

        /// <summary>
        /// Value which indicates that the operation is a disjunction, like <c>a || b</c>.
        /// </summary>
        Disjunction

        #endregion

    }

}
