/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

using Aran.Core;
using Aran.Searching;

namespace Aran.Searching.Specialized {

    /// <summary>
    /// Represents an <see cref="EnforcedHillClimbingAlgorithm">Enforced Hill Climbing algorithm</see> node.
    /// </summary>
    [Serializable]
    internal sealed class EnforcedHillClimbingNode {

        #region Constants

        /// <summary>
        /// The constant which represents no <see cref="EnforcedHillClimbingNode">node</see>.
        /// </summary>
        internal const EnforcedHillClimbingNode None = null;

        #endregion

        #region Fields

        /// <summary>
        /// The <see cref="State">state</see> contained by the node.
        /// </summary>
        internal readonly State State;

        /// <summary>
        /// The next <see cref="EnforcedHillClimbingNode">node</see> of the open list.
        /// </summary>
        internal EnforcedHillClimbingNode Next;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="EnforcedHillClimbingNode"/> class.
        /// </summary>
        /// <remarks>
        /// Assumes the correction of <see cref="State">state</see>, as a performance improvement. If needed,
        /// correction checks must be done previously to the call of this constructor.
        /// </remarks>
        internal EnforcedHillClimbingNode(State state) {
            State = state;
        }

        #endregion

    }

}
