/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

using Aran.Core;
using Aran.Searching;

namespace Aran.Searching.Specialized {

    /// <summary>
    /// Represents a <see cref="IStateParentSetter{T}">state parent setter</see> capable of setting a
    /// parent-successor relation between a couple of <see cref="State">state</see>s via
    /// <see cref="State.SetParent">the method provided by them</see>.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class StateParentalManager : IStateParentSetter<State> {

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="StateParentalManager"/> class.
        /// </summary>
        public StateParentalManager() {
            //do nothing
        }

        #endregion

        #region Methods

        /// <summary>
        /// Sets the a parent-successor relation between a couple of specified states of a
        /// <see cref="ISearchAlgorithm{T}">search algorithm</see>.
        /// </summary>
        /// <param name="state">The state whose parent is going to be set.</param>
        /// <param name="parent">The state to be set as the parent of <paramref name="state"/>.</param>
        public void SetParent(State state, State parent) {
            state.SetParent(parent);
        }

        /// <summary>
        /// Resets the internal information accumulated while setting parent-successor relations.
        /// </summary>
        public void Reset() {
            //do nothing
        }

        #endregion

    }

}
