/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Searching {

    /// <summary>
    /// Represents an <see cref="AStarAlgorithm{T}">A* algorithm</see> node.
    /// </summary>
    /// <typeparam name="T">The type of the states.</typeparam>
    [Serializable]
    internal sealed class AStarNode<T> : BestFirstNode<T, AStarNode<T>> {

        #region Fields

        /// <summary>
        /// The estimated cost of reaching a goal state from the initial one passing by
        /// <see cref="BestFirstNode{T, N}.State"/>.
        /// </summary>
        internal float EstimatedTotalCost;

        /// <summary>
        /// The estimated cost of reaching a goal state from <see cref="BestFirstNode{T, N}.State"/>.
        /// </summary>
        internal float EstimatedRemainingCost;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="AStarNode{T}"/> class.
        /// </summary>
        public AStarNode() {
            //do nothing
        }

        #endregion

        #region Methods

        /// <summary>
        /// Gets the cost difference from this node to other.
        /// </summary>
        /// <param name="other">The other node.</param>
        /// <returns>
        /// The cost difference from this node to <paramref name="other"/>
        /// </returns>
        protected override float GetCostDifference(AStarNode<T> other) {
            return EstimatedTotalCost - other.EstimatedTotalCost;
        }

        #endregion

    }

}
