/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Searching {

    /// <summary>
    /// Represents an <see cref="Object">object</see> which provides always the same initial state for a
    /// <see cref="ISearchAlgorithm{T}">search algorithm</see>.
    /// </summary>
    /// <typeparam name="T">The type of the states.</typeparam>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class ConstantInitialStateProvider<T> : IInitialStateProvider<T> {

        #region Fields

        /// <summary>
        /// The always-provided initial state.
        /// </summary>
        private T _initialState;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ConstantInitialStateProvider{T}"/> class.
        /// </summary>
        /// <param name="initialState">The initial state to be always provided.</param>
        public ConstantInitialStateProvider(T initialState) {
            _initialState = initialState;
        }

        #endregion

        #region Properties

        /// <summary>
        /// Gets the initial state.
        /// </summary>
        /// <returns>The initial state.</returns>
        public T GetInitialState() {
            return _initialState;
        }

        #endregion

    }

}
