/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Searching {

    /// <summary>
    /// Represents a Dijkstra algorithm node.
    /// </summary>
    /// <typeparam name="T">The type of the states.</typeparam>
    [Serializable]
    internal sealed class DijkstraNode<T> : BestFirstNode<T, DijkstraNode<T>> {

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="DijkstraNode{T}"/> class.
        /// </summary>
        public DijkstraNode() {
            //do nothing
        }

        #endregion

        #region Methods

        /// <summary>
        /// Gets the cost difference from this node to other.
        /// </summary>
        /// <param name="other">The other node.</param>
        /// <returns>
        /// The cost difference from this node to <paramref name="other"/>
        /// </returns>
        protected override float GetCostDifference(DijkstraNode<T> other) {
            return Cost - other.Cost;
        }

        #endregion

    }

}
