/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;
using System.Collections.Generic;

namespace Aran.Searching {

    /// <summary>
    /// Represents an <see cref="Object">object</see> capable of providing the successors of a state of a
    /// <see cref="ISearchAlgorithm{T}">search algorithm</see>.
    /// </summary>
    /// <typeparam name="T">The type of the states.</typeparam>
    [CLSCompliant(true)]
    public interface IStateSuccessorsProvider<T> {

        #region Methods

        /// <summary>
        /// Gets the successors of a specified state of a <see cref="ISearchAlgorithm{T}">search algorithm</see>.
        /// </summary>
        /// <param name="state">The state.</param>
        /// <returns>The successors of <paramref name="state"/>.</returns>
        IEnumerable<T> GetSuccessors(T state);

        #endregion

    }

}
