/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Searching {

    /// <summary>
    /// Represents an <see cref="IStateHeuristicCostProvider{T}">heuristic cost provider</see> which
    /// always returns 0, regardless of the state.
    /// </summary>
    [CLSCompliant(true)]
    [Serializable]
    public sealed class NullHeuristic<T> : IStateHeuristicCostProvider<T> {

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="NullHeuristic{T}"/> class.
        /// </summary>
        public NullHeuristic() {
            //do nothing
        }

        #endregion

        #region Methods

        /// <summary>
        /// Gets the estimated cost of reaching a goal state of a
        /// <see cref="ISearchAlgorithm{T}">search algorithm</see> from the specified one.
        /// </summary>
        /// <param name="state">The state.</param>
        /// <returns>
        /// The estimated cost of reaching a goal state of a
        /// <see cref="ISearchAlgorithm{T}">search algorithm</see> from <paramref name="state"/>.
        /// </returns>
        public float GetHeuristicCost(T state) {
            return 0;
        }

        #endregion

    }

}
