/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Translation {

    /// <summary>
    /// Represents a global message counter set.
    /// </summary>
    [Serializable]
    internal abstract class MessageCounters {

        /*
         * NOTE: The current implementation of this translator is functional but highly improvable in all ways:
         * design, clarity, readability, performance... Its current state derives from an incomplete requirement
         * discovering phase so that the final desing and implementation was done by adding multiple
         * modifications during the development in order to fullfil all the final requirements discovered. This
         * desing relies on an enormous main type (Translator) instead of divide its funcionality into many other
         * helper types. In addition, the desing of the main type and all others does not make a correct use of
         * Object Oriented techniques in order to reduce the amount of repeated or similar code. Future
         * implementations may correct these errors.
         */

        #region Fields

        /// <summary>
        /// The number of semantic warnings.
        /// </summary>
        internal int SemanticWarnings;

        /// <summary>
        /// The number of semantic errors.
        /// </summary>
        internal int SemanticErrors;

        /// <summary>
        /// The number of syntactic errors.
        /// </summary>
        internal int SyntacticErrors;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MessageCounters"/> class.
        /// </summary>
        protected internal MessageCounters() {
		    //do nothing
        }

        #endregion

        #region Methods

        /// <summary>
        /// Interrupts the translation.
        /// </summary>
        internal abstract void InterruptTranslation();

        #endregion

    }

}