/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Translation {

    /// <summary>
    /// Represents an object.
    /// </summary>
    [Serializable]
    internal sealed class Object {

        /*
         * NOTE: The current implementation of this translator is functional but highly improvable in all ways:
         * design, clarity, readability, performance... Its current state derives from an incomplete requirement
         * discovering phase so that the final desing and implementation was done by adding multiple
         * modifications during the development in order to fullfil all the final requirements discovered. This
         * desing relies on an enormous main type (Translator) instead of divide its funcionality into many other
         * helper types. In addition, the desing of the main type and all others does not make a correct use of
         * Object Oriented techniques in order to reduce the amount of repeated or similar code. Future
         * implementations may correct these errors.
         */

        #region Constants

        /// <summary>
        /// A constant wich represents no type identifier.
        /// </summary>
        internal const int NoTypeId = -1;

        #endregion

        #region Fields

        /// <summary>
        /// The identifiers of the object depending on the type.
        /// </summary>
        /// <remarks>Each position has either a type identificer or <see cref="NoTypeId">nothing</see>.
        /// Position <c>i</c> represents the type <c>i</c> so that if the object is of that type then position
        /// <c>i</c> has an identifier and <see cref="NoTypeId">nothing</see> otherwise.</remarks>
        internal int[] TypeDependantIds;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="Object"/> class.
        /// </summary>
        internal Object() {
            //do nothing
        }

        #endregion

    }

}
