/* Aran, an XNA-compliant .NET automated planning framework
 * Copyright (C) 2008 Abel Garca Plaza
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

using System;

namespace Aran.Translation {

    /// <summary>
    /// Represents an <see cref="Object">object</see> capable of interrupting the translation process.
    /// </summary>
    /// <typeparam name="TType">The type of the type identifiers.</typeparam>
    /// <typeparam name="TPred">The type of the predicate identifiers.</typeparam>
    /// <typeparam name="TFunc">The type of the function identifiers.</typeparam>
    /// <typeparam name="TOp">The type of the operator identifiers.</typeparam>
    /// <typeparam name="TObj">The type of the object identifiers.</typeparam>
    /// <typeparam name="TFact">The type of the fact identifiers.</typeparam>
    /// <typeparam name="TVar">The type of the variable identifiers.</typeparam>
    [Serializable]
    internal sealed class TranslationInterrupter<TType, TPred, TFunc, TOp, TObj, TFact, TVar> : MessageCounters {

        /*
         * NOTE: The current implementation of this translator is functional but highly improvable in all ways:
         * design, clarity, readability, performance... Its current state derives from an incomplete requirement
         * discovering phase so that the final desing and implementation was done by adding multiple
         * modifications during the development in order to fullfil all the final requirements discovered. This
         * desing relies on an enormous main type (Translator) instead of divide its funcionality into many other
         * helper types. In addition, the desing of the main type and all others does not make a correct use of
         * Object Oriented techniques in order to reduce the amount of repeated or similar code. Future
         * implementations may correct these errors.
         */

        #region Fields

        /// <summary>
        /// The resource manager.
        /// </summary>
        private readonly Resources _resources;

        /// <summary>
        /// The translator messages.
        /// </summary>
        private readonly MessageManager<TType, TPred, TFunc, TOp, TObj, TFact, TVar> _messages;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the
        /// <see cref="TranslationInterrupter{TType, TPred, TFunc, TOp, TObj, TFact, TVar}"/> class.
        /// </summary>
        /// <param name="resources">The resource manager.</param>
        /// <param name="messages">The translator messages.</param>
        internal TranslationInterrupter(Resources resources,
        MessageManager<TType, TPred, TFunc, TOp, TObj, TFact, TVar> messages) {
            _resources = resources;
            _messages = messages;
        }

        #endregion

        #region Methods

        /// <summary>
        /// Interrupts the translation.
        /// </summary>
        /// <exception cref="GenerationException{TType, TPred, TFunc, TOp, TObj, TFact, TVar}">Always.</exception>
        internal override void InterruptTranslation() {
            throw new GenerationException<TType, TPred, TFunc, TOp, TObj, TFact, TVar>(
                _resources.GenerationErrorsFound, _messages);
        }

        #endregion

    }

}